@@ -28,8 +28,9 @@
 #include <KCModuleProxy>
 #include <KLocalizedString>
 #include <KPluginMetaData>
-#include <KQuickAddons/QtQuickSettings>
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 92)
 #include <KServiceTypeTrader>
+#endif
 #include <KStartupInfo>
 #include <kworkspace.h>
 
@@ -44,7 +45,7 @@ inline QVector<KPluginMetaData> findKCMsMetaData()
     metaDataList << KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms/kinfocenter"));
     return metaDataList;
 }
-
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 92)
 static KService::List listModules()
 {
     // First condition is what systemsettings does, second what kinfocenter does, make sure this is kept in sync
@@ -91,6 +92,7 @@ static KService::Ptr locateModule(const QString &module)
 
     return service;
 }
+#endif
 
 bool KCMShell::isRunning()
 {
@@ -174,10 +176,9 @@ int main(int _argc, char *_argv[])
         qunsetenv("QT_QPA_PLATFORM");
     }
     KLocalizedString::setApplicationDomain("kcmshell5");
-    KQuickAddons::QtQuickSettings::init();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     KAboutData aboutData(QStringLiteral("kcmshell5"), //
                          i18n("System Settings Module"),
                          QLatin1String(PROJECT_VERSION),
@@ -218,12 +219,13 @@ int main(int _argc, char *_argv[])
         std::cout << i18n("The following modules are available:").toLocal8Bit().constData() << '\n';
 
         QVector<KPluginMetaData> plugins = findKCMsMetaData();
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 92)
         const KService::List services = listModules();
         for (const auto &service : services) {
             const QString file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("/kservices5/") + service->entryPath());
             plugins << KPluginMetaData::fromDesktopFile(file);
         }
-
+#endif
         int maxLen = 0;
 
         for (const auto &plugin : plugins) {
@@ -275,6 +277,7 @@ int main(int _argc, char *_argv[])
             if (foundKCM) {
                 continue;
             }
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 92)
             KService::Ptr service = locateModule(arg);
             if (!service) {
                 service = locateModule(QStringLiteral("kcm_") + arg);
@@ -295,6 +298,7 @@ int main(int _argc, char *_argv[])
             } else {
                 std::cerr << i18n("Could not find module '%1'. See kcmshell5 --list for the full list of modules.", arg).toLocal8Bit().constData() << std::endl;
             }
+#endif
         }
     }
 
